<div dir="rtl">

# پکیج Neshan

با استفاده از این پکیج می توانید از سرویس های پلتفرم نقشه نشان استفاده نمایید

# نصب

برای نصب از طریق `pip` کافیه تا دستور زیر را اجرا کنید
```
pip install pod-neshan
```


# نمونه کد

نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>
